
# Slot: edge_type_list_header


Whether the edge type file has an header.

URI: [https://w3id.org/neat/ensmallenRunConfig__edge_type_list_header](https://w3id.org/neat/ensmallenRunConfig__edge_type_list_header)


## Domain and Range

None &#8594;  <sub>0..1</sub> [Boolean](types/Boolean.md)

## Parents


## Children


## Used by

 * [EnsmallenRunConfig](EnsmallenRunConfig.md)
